@@ -108,7 +108,7 @@ def proc_slider(
     proc_file_dir = "%s%s%s" % (out_path, path_separator, image_proc_file_name)
 
     image_unchanged = cv2.imread(image_dir, cv2.IMREAD_UNCHANGED)  # 4个通道
-    image_gray = cv2.cvtColor(image_unchanged, cv2.COLOR_BGR2GRAY)  # 转换为灰度图
+    image_gray = cv2.cvtColor(image_unchanged, cv2.COLOR_BGR2GRAY)  # 转换为灰度图，只有1个通道
 
     height = image_gray.shape[0]  # 高
     weight = image_gray.shape[1]  # 宽
@@ -118,16 +118,18 @@ def proc_slider(
             # 遍历图像的每个像素
             if alpha_white_max is not None:
                 if image_unchanged[each_height, each_weight][3] <= alpha_white_max:
-                    image_gray[each_height, each_weight] = 255  # 判定为最白区域的，直接改为白色
+                    image_unchanged[each_height, each_weight] = [0, 0, 0, 0]  # 判定为透明区域的，直接改为纯透明
                 else:
-                    image_gray[each_height, each_weight] = 0  # 其他区域直接改为黑色
+                    image_unchanged[each_height, each_weight] = [0, 0, 0, 255]  # 判定为不透明区域的，直接改为黑色不透明
             else:
                 if image_gray[each_height, each_weight] >= white_value_max:
                     image_gray[each_height, each_weight] = 255  # 判定为最白区域的，直接改为白色
                 else:
                     image_gray[each_height, each_weight] = 0  # 其他区域直接改为黑色
-
-    cv2.imwrite(proc_file_dir, image_gray)
+    if alpha_white_max is None:
+        cv2.imwrite(proc_file_dir, image_gray)  # 存储灰度图
+    else:
+        cv2.imwrite(proc_file_dir, image_unchanged)
     return proc_file_dir
 
 
